import time
from quick_crawler import page
from selenium import webdriver

def get_page_content_with_browser(url,chrome_driver_path):

    options = webdriver.ChromeOptions()
    # options.add_argument("headless")
    # set chromedriver.exe's path
    driver = webdriver.Chrome(executable_path=chrome_driver_path,
                              # chrome_options=options
                              )
    driver.implicitly_wait(0.5)
    # launch the page
    driver.get(url)

    html_obj = driver.find_element_by_tag_name("html")

    time.sleep(5)
    html_str=html_obj.get_attribute("outerHTML")
    from bs4 import BeautifulSoup
    # html = BeautifulSoup(html_obj.get_attribute("outerHTML"), features='lxml')
    # find elements
    # table_obj = driver.find_element_by_tag_name("table")
    # obtain target htmlstr
    # print(table_obj.get_attribute("outerHTML"))
    driver.close()
    return html_str

def get_country_list(chrome_driver="browsers/chromedriver.exe",read_countries_file="datasets/countries.csv", save_dataset_path="datasets"):
    # quick read csv file to a list of fields
    list_result = page.quick_read_csv(read_countries_file,
                                      fields=['Id', 'Url', 'English Name', 'French Name', 'Local Name', 'Region'])
    print(list_result)
    for country in list_result:
        id = country[0]
        url = country[1]
        print(url)
        html_str = get_page_content_with_browser(url,chrome_driver_path=chrome_driver)
        f_out = open(save_dataset_path, "w", encoding='utf-8')
        f_out.write(html_str)
        f_out.close()









import uuid
import requests
import time
import json
# pip install quick_crawler
from quick_crawler.page import quick_html_page
from quick_crawler.browser import check_url_ok

class Carbon2Api:
    def __init__(self,root_url):
        self.root_url=root_url

    def exists_url(self,url):
        api_url = f'{self.root_url}/Data'

        parameters = {"Url": url
                      }

        r = requests.get(api_url, params=parameters)
        # print(r.text)
        result_obj=json.loads(r.text)
        return int(result_obj["Result"])

    def submit_metadata(self,url,title,uploader,publisher="",publishtime="",keywords="",description="",html="",language="",baidu_url="",search_keywords="",remark="",tag="",file_id=""):
        api_url = f'{self.root_url}/Data'

        parameters = {"Url": url,
                      "Title": title,
                      "Publisher": publisher,
                      "PublishTime": publishtime,
                      "Keywords": keywords,
                      "Description": description,
                      "Html": html, # 这个可以设置为空，因为是后面会有上传，不需要录入数据库
                      "Language": language,
                      "Uploader": uploader,# 用户的姓名全拼，用于区分不同用户的数据
                      "AddTime": time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()),
                      "BaiduUrl": baidu_url,
                      "SearchKeywords": search_keywords,
                      "Remark": remark,
                      "Tag": tag,
                      "FileId": file_id,
                      }
        r = requests.post(api_url, params=parameters)
        print(r.text)
        result_obj=json.loads(r.text)
        return int(result_obj["Result"])

    def submit_file(self,file_path):
        files = [
            ('file_1', open(file_path, 'rb')),
           # ('file_2', open('data/baidu_peark_carbon_emission_opinion.txt', 'rb')),
        ]
        resp = requests.post(f'{self.root_url}/Data',  files=files)
        # print(resp.request.body.decode('utf-8'))
        return resp.text









import requests
import json
from quick_crawler.page import quick_html_page,quick_html_object,quick_download_file,quick_save_csv
from quick_crawler.browser import get_html_str_with_browser
import os

def download_data_from_server(server_url,page_count,save_rawdata_folder,save_csv_path):
    api_url = f"{server_url}/api/Data"
    list_model = []
    fields = []
    for page_index in range(1,page_count+1):# page count
        parameters = {
            "PageIndex": page_index,
            "PageSize": 100
        }
        r = requests.get(api_url, params=parameters)
        page = json.loads(r.text)
        # print(page)
        print("page index = ",page_index)
        # print("PageCount:", page["PageCount"])

        for row in page["DataTable"]:
            # print(row)
            if len(fields) == 0:
                fields = row.keys()
                print(fields)
            file_id = row["FileId"]
            download_fulltext_url = f"{server_url}/WebData/{file_id}.txt"
            save_path = f"{save_rawdata_folder}/{file_id}.txt"
            if not os.path.exists(save_path):
                try:
                    quick_download_file(download_fulltext_url, save_file_path=save_path)
                except:
                    print("error in downloading file", download_fulltext_url)
            list_model.append(row)
    quick_save_csv(save_csv_path, field_names=fields, list_rows=list_model)
